## ----style, echo = FALSE, results = 'asis'------------------------------------
BiocStyle::markdown()
knitr::opts_chunk$set(fig.wide = TRUE, fig.retina = 3, error=FALSE, eval=TRUE)

## ----rawDiagLogo, echo=FALSE, out.width="50%", fig.cap="The octopussy `rawDiag` package logo by Lilly van de Venn."----
knitr::include_graphics("octopussy.png")

## ----checkRequirements, echo=TRUE---------------------------------------------
rawDiag::checkRawrr
rawDiag::checkRawrr()

## ----fetchFromExperimentHub, echo=FALSE---------------------------------------
## fetch via ExperimentHub
library(ExperimentHub)
eh <- ExperimentHub(localHub = FALSE)
EH4547 <- normalizePath(eh[["EH4547"]])

(rawfile <- paste0(EH4547, ".raw"))
if (!file.exists(rawfile)){
  file.copy(EH4547, rawfile)
}

## ----readEH4547OrbitrapTrailerTable-------------------------------------------
## read Orbitrap meta data
rawfile |>
  rawDiag::readRaw() -> x

## ----listFUN------------------------------------------------------------------
library(rawDiag)
ls("package:rawDiag") |>
  grep(pattern = '^plot', value = TRUE) -> pm

pm |>
  knitr::kable(col.names = "package:rawDiag plot functions")

## ----plotALL, echo = FALSE, fig.width = 10, fig.height = 5--------------------
pm |> 
  lapply(FUN = function(plotFUN) {
    lapply(c('trellis'), function(method) {
    #lapply(c('trellis', 'violin', 'overlay'), function(method) {
      message(paste0("plotting", plotFUN, "using method", method, "..."))
      do.call(plotFUN, list(x, method)) 
    })
  }) 

## ----sessioninfo, echo=FALSE, eval=TRUE---------------------------------------
sessionInfo()

